<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>EditEvent</name>
    <message>
        <source>Edit Event</source>
        <translation>Editar Evento</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Comece:
</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Ação se evento prévio ainda está tocando
</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Inicie Imediatamente
</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Espere até</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Start Transition Type:</source>
        <translation>Tipo de Transição ao iniciar:
</translation>
    </message>
    <message>
        <source>No Fade at Segue Out</source>
        <translation>Sem Sobreposição de Fade na Saída</translation>
    </message>
    <message>
        <source>&amp;Audition</source>
        <translation type="obsolete">&amp;Audição</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation type="obsolete">&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation type="obsolete">&amp;Pare</translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="obsolete">Início</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="obsolete">Fim</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Edit Marker</source>
        <translation type="unfinished">Editar Marcador</translation>
    </message>
    <message>
        <source>Edit Track</source>
        <translation type="unfinished">Editar Pista</translation>
    </message>
    <message>
        <source>Edit Log Track</source>
        <translation type="unfinished">Editar Pista da Lista</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Transição se o Cartão anterior Terminar Antes</translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation>Duplicar Hora de Início</translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation>Um evento já está agendado com esta hora de início!</translation>
    </message>
    <message>
        <source>Cart Notes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HourSelector</name>
    <message>
        <source>12a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>12p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11p</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLog</name>
    <message>
        <source>EST TIME</source>
        <translation type="obsolete">HORA EST</translation>
    </message>
    <message>
        <source>LEN</source>
        <translation type="obsolete">DURAÇÃO</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="obsolete">TRANSIÇÃO</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">CART</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TÍTULO</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">ARTISTA</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPO</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="obsolete">HORA PROGRAMDA</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="obsolete">CLIENTE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="obsolete">AGÊNCIA</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="obsolete">SELO</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation type="obsolete">ID de LINHA</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="obsolete">CONTADOR</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation type="obsolete">STATUS</translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation>Durações</translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation>Próxima Parada:</translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation>Fim da Lista:</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Selecionar</translation>
    </message>
    <message>
        <source>Audition
Head</source>
        <translation>Audição
Início</translation>
    </message>
    <message>
        <source>Audition
Tail</source>
        <translation>Audição
Fim</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Início</translation>
    </message>
    <message>
        <source>Make
Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Modify</source>
        <translation>Modificar</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Rolagem</translation>
    </message>
    <message>
        <source>Refresh
Log</source>
        <translation>Atualizar </translation>
    </message>
    <message>
        <source>Select
Log</source>
        <translation>Sel Lista</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="obsolete">Lista Existe</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="obsolete">Lista já Existe!</translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation>Selecionado:</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>Fim da Lista</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>TOQUE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>PARE</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SOBRE</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARCADOR</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>PISTA</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LINK</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[importar música]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[importar tráfego]</translation>
    </message>
    <message>
        <source>CHAIN TO</source>
        <translation>CORRENTE PARA</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[CART NÃO ENCONTRADO]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[NÃO HÁ CONTEÚDO VÁLIDO]</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[NÃO HÁ ÁUDIO VÁLIDO]</translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished">T</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Len</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Est. Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sch. Time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation type="obsolete">Sel uma Lista</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="obsolete">NOME</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">Descrição</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">SERVIÇO</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Carregar</translation>
    </message>
    <message>
        <source>Unload</source>
        <translation>Descarregar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="obsolete">Salvar &amp;Como</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Rename Log</source>
        <translation>Renomear lista</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log already being edited by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must refresh the log before it can be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogLineBox</name>
    <message>
        <source>STOP</source>
        <translation>PARE</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SOBRE</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[CART NÃO ENCONTRADO]</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[NÃO HÁ ÁUDIO VÁLIDO]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[NÃO HÁ CONTEÚDO VÁLIDO]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARCADOR</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>PISTA</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LINK</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[importar música]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[importar tráfego]</translation>
    </message>
    <message>
        <source>CHAIN</source>
        <translation>CORRENTE </translation>
    </message>
    <message>
        <source>T</source>
        <translation type="obsolete">T</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDAirPlay</source>
        <translation>RaDAr</translation>
    </message>
    <message>
        <source>Multiple instances not allowed!</source>
        <translation>Não é permitido múltiplas instâncias</translation>
    </message>
    <message>
        <source>RDAirPlay - Host:</source>
        <translation type="obsolete">RDAovivo - Cliente:</translation>
    </message>
    <message>
        <source>Database Error</source>
        <translation type="obsolete">Erro na Base de Dados</translation>
    </message>
    <message>
        <source>ADD</source>
        <translation>+</translation>
    </message>
    <message>
        <source>DEL</source>
        <translation>DEL
</translation>
    </message>
    <message>
        <source>MOVE</source>
        <translation>MOVER
</translation>
    </message>
    <message>
        <source>COPY</source>
        <translation>COPIAR
</translation>
    </message>
    <message>
        <source>Main Log
[--]</source>
        <translation>Lista Principal 
[--]
</translation>
    </message>
    <message>
        <source>Aux 1 Log
[--]</source>
        <translation>LIsta Auxiliar 1
[--]
</translation>
    </message>
    <message>
        <source>Aux 2 Log
[--]</source>
        <translation>Lista Auxiliar 2
[--]</translation>
    </message>
    <message>
        <source>Sound
Panel</source>
        <translation>Painel
de Sons</translation>
    </message>
    <message>
        <source>Main Log</source>
        <translation>Lista Principal</translation>
    </message>
    <message>
        <source>Aux 1 Log</source>
        <translation>Lista Auxiliar 1</translation>
    </message>
    <message>
        <source>Aux 2 Log</source>
        <translation>Lista Auxiliar 2</translation>
    </message>
    <message>
        <source>LOG
REFRESHING</source>
        <translation>ATUALIZANDO
LISTA</translation>
    </message>
    <message>
        <source>Exit RDAirPlay?</source>
        <translation>Sair do RaDAr?</translation>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Memory Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to lock all memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log channel assignments are invalid!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModeDisplay</name>
    <message>
        <source>Operating Mode</source>
        <translation type="unfinished">Modo de Operação</translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation>Manuauto</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual
</translation>
    </message>
    <message>
        <source>A1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PostCounter</name>
    <message>
        <source>Next Timed Start</source>
        <translation>Próxima com hora certa</translation>
    </message>
    <message>
        <source>On Time</source>
        <translation>No horário</translation>
    </message>
    <message>
        <source>Next Timed Start [--:--:--]</source>
        <translation>Próxima com hora certa [--:--:--]

</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>START</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">PARE</translation>
    </message>
    <message>
        <source>PAUSE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RESUME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WHERE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DELETE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOVE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TO?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COPY?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ERROR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StopCounter</name>
    <message>
        <source>Next Stop [none]</source>
        <translation>Próxima Parada [nehum]</translation>
    </message>
    <message>
        <source>Next Stop</source>
        <translation>Próxima Parada</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Parado</translation>
    </message>
</context>
</TS>
